from PyErr import ArgError as _ArgError

def write(name, value):
    err = _ArgError("Parameter 'value' is not parsable") 
    if not isinstance(value, str):
        raise err
    if value.replace('0', '').replace('1', ''):
        raise err
    if len(value)%8:
        raise err
    tridouble = lambda x: x*8
    result = b''
    for i in map(tridouble, range(int(len(value)/8))):
        b = '0b'+value[i:i+8]
        h = 'b\'\\'+hex(eval(b))[1:]+'\''
        result += eval(h)
    with open(name, 'wb') as f:
        f.write(result)


_builtin_open = open

def read(name):
    with _builtin_open(name, 'rb') as f:
        s = str(f.read())[2:-1]
    result = ''
    redouble = lambda x: x*4
    for i in map(redouble, range(int(len(s)/4))):
        parsing = '0x'+s[i+2:i+4]
        parsing = eval(parsing)
        result += bin(parsing)[2:]
    return result


import setuptools

with open("README.md") as fh:
    long_description = fh.read()

setuptools.setup(
    name="PyBinF",
    version="0.1.1",
    author="Frank Lin",
    author_email="W_126mail@126.com",
    description="Python binary files parser",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/usr8820/PyBinF/",
    packages=['PyBF'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.0',
    install_requires=['PyErrs']
)